@@ -4,16 +4,15 @@ Download files with DownloadData.
 import logging
 from os import PathLike, makedirs, remove, stat
 from os.path import isfile
-from typing import Tuple, List
+from typing import List, Tuple
 
 from pySmartDL import SmartDL, utils
 
-from animethemes_dl.options import OPTIONS, setOptions
-
 from .errors import BadThemesUrl
 from .models import DownloadData, Options
+from .options import OPTIONS, setOptions
 from .parsers import get_download_data
-from .tools import add_id3_metadata, compress_files, ffmpeg_convert, fix_faulty_url
+from .tools import DLCACHEDIR, add_id3_metadata, compress_files, ffmpeg_convert, fix_faulty_url
 
 logger = logging.getLogger('animethemes-dl')
 
@@ -46,7 +45,7 @@ def download_video(data: DownloadData, use_temp: bool=False):
     Returns destination
     """
     if use_temp:
-        dest = None
+        dest = DLCACHEDIR
     else:
         dest = data['video_path']
     
@@ -84,14 +83,14 @@ def convert_audio(data: DownloadData, video_path: PathLike=None):
     Converts webm video into audio and adds metadata.
     Can force a different video path.
     """
-    data['video_path'] = data['video_path'] or video_path
     try:
-        ffmpeg_convert(data['video_path'],data['audio_path'])
+        ffmpeg_convert(data['video_path'] or video_path, data['audio_path'])
     except KeyboardInterrupt as e:
         # delete unfinished ffmpeg conversions
         if isfile(data['audio_path']):
             remove(data['audio_path'])
         quit(e)
+    
     add_id3_metadata(data['audio_path'],data['metadata'],data['info']['malid'])
 
 def download_theme(data: DownloadData, dlvideo: bool=True, dlaudio:bool=True):
@@ -158,7 +157,7 @@ def batch_download(options: dict=Options):
     logger.info('[progress] initializing animethemes-dl')
     data = get_download_data(
         OPTIONS['animelist']['username'],
-        OPTIONS['animelist']['anilist'],
+        OPTIONS['animelist']['site'],
         OPTIONS['animelist']['animelist_args']
     )
     batch_download_themes(data)
@@ -166,32 +165,3 @@ def batch_download(options: dict=Options):
     
     if OPTIONS['compression']['root_dir']:
         compress_files(**OPTIONS['compression'])
-
-if __name__ == '__main__':
-    logging.basicConfig(
-        format='%(message)s'
-    )
-    logger.setLevel(logging.DEBUG)
-    batch_download({
-        'animelist':{
-            'username':'sadru',
-            'minscore':9,
-            'minpriority':2
-        },
-        'filter':{
-            'entry': {
-                'spoiler':False
-            }
-        },
-        'download':{
-            'audio_folder':'anime_themes/audio',
-            'video_folder':'anime_themes/video',
-            'no_redownload':True,
-            'coverart': {
-                'resolution': 3,
-                'folder': 'anime_themes/coverarts'
-            },
-            'timeout':15
-        },
-        # 'ffmpeg':'./ffmpeg.exe'
-    })
